//////////////////////////////////////////////////////////////
// install.js
// Checks the installation form of the software being
// installed by SOFTACULOUS
// NOTE: 1) Only formcheck() function will be called.
//       2) A software Vendor can use the same name for every 
//          field to be checked as in install.xml . It can be
//          called using $('fieldname').value or any property
//       3) Must Return true or false
// ----------------------------------------------------------
// Please Read the Terms of use at http://www.softaculous.com
// ----------------------------------------------------------
// (c)Softaculous Inc.
//////////////////////////////////////////////////////////////

function formcheck(){
	
	//Check the Admin Email
	if(window.check_punycode){
		if(!check_punycode($('admin_email').value)){
			alert('{{err_ademail}}');
			return false;
		}
		
		return true;
	}
	
	return true;
};

//we need to hide pro plugin description below wordpress 6.6
document.querySelectorAll(".plugins-list").forEach(function (element) {
    const parentDiv = element.parentElement;

    if (parentDiv && parentDiv.parentElement) {
        const siblingSpans = parentDiv.parentElement.querySelectorAll(":scope > span");
        
        siblingSpans.forEach(function (span) {
            if (span.offsetParent !== null) {
                setTimeout(function () {
                    span.style.display = "none";
                }, 100);
            }
        });
    }
});